@@ -25,10 +25,9 @@
 
 #include "generictypes.h"
 
-#include <nm-version.h>
-#if NM_CHECK_VERSION(1, 0, 0)
+#undef signals
 #include <libnm/NetworkManager.h>
-#endif
+#define signals Q_SIGNALS
 
 #include <QtCore/QVariantMap>
 #include <QtCore/QStringList>
@@ -48,12 +47,47 @@ class NETWORKMANAGERQT_EXPORT Setting
 public:
     typedef QSharedPointer<Setting> Ptr;
     typedef QList<Ptr> List;
-    enum SettingType {Adsl, Cdma, Gsm, Infiniband, Ipv4, Ipv6, Ppp, Pppoe, Security8021x, Serial,
-                      Vpn, Wired, Wireless, WirelessSecurity, Bluetooth, OlpcMesh, Vlan, Wimax, Bond, Bridge, BridgePort, Team, Generic
-                     };
-    enum SecretFlagType {None = 0, AgentOwned = 0x01, NotSaved = 0x02, NotRequired = 0x04};
+    enum SettingType {
+        Adsl,
+        Cdma,
+        Gsm,
+        Infiniband,
+        Ipv4,
+        Ipv6,
+        Ppp,
+        Pppoe,
+        Security8021x,
+        Serial,
+        Vpn,
+        Wired,
+        Wireless,
+        WirelessSecurity,
+        Bluetooth,
+        OlpcMesh,
+        Vlan,
+        Wimax,
+        Bond,
+        Bridge,
+        BridgePort,
+        Team,
+        Generic,
+        Tun
+    };
+
+    enum SecretFlagType {
+        None = 0,
+        AgentOwned = 0x01,
+        NotSaved = 0x02,
+        NotRequired = 0x04
+    };
     Q_DECLARE_FLAGS(SecretFlags, SecretFlagType)
 
+    enum MacAddressRandomization {
+        MacAddressRandomizationDefault = 0,
+        MacAddressRandomizationNever,
+        MacAddressRandomizationAlways
+    };
+
     static QString typeAsString(SettingType type);
     static SettingType typeFromString(const QString &type);
 
